# Auto-generated from agentskills.io specification
# Do not edit manually - run scripts/fetch_spec_schema.py to update
from __future__ import annotations

from typing import Final

MAX_NAME_LENGTH: Final[int] = 64
MAX_DESCRIPTION_LENGTH: Final[int] = 1024
MIN_DESCRIPTION_LENGTH: Final[int] = 1
MAX_COMPATIBILITY_LENGTH: Final[int] = 500
